
/**
 * Process the content of the MachAnt script, replacing the following
 * placeholders with the values held in the Netcool Installer Property manager.
 * __NGF_WEBSERVER_PORT__
 * __ADMIN_USERNAME__
 * __ADMIN_PASSWORD__
 * __NCHOME__
 *
 * @param machantScript the name of the MachAnt file to process, which must be
 * in $NCHOME/etc/precision/antonce and have the extension .orig
 */
function processMachAntScript(machantScript, target)
{
	log( 2, "Processing MachAnt script..." );

	var antScript = transformPathSeparators( getNchome() + "/etc/precision/antonce/" + machantScript + ".orig" );

	log( 2, "Configuring " + antScript );

	var antScriptContents = readFromFile( antScript );

	var propMgr = Components.classes["@micromuse.com/NCIProperties;1"].
		getService(Components.interfaces.nsINCIProperties);

	var mainHttpServerPort = propMgr.GetProp("GUIFOUNDATION.WEBSERVER.PORT").value;
	var mainHttpServerUsername = propMgr.GetProp("NCSM0.ADMIN.USERNAME").value;
	var mainHttpServerPassword = propMgr.GetProp("NCSM0.ADMIN.PASSWORD").value;

	var newAntScriptContents = antScriptContents.replace( /__NGF_WEBSERVER_PORT__/g,
		mainHttpServerPort );

	newAntScriptContents = newAntScriptContents.replace( /__ADMIN_USERNAME__/g,
		mainHttpServerUsername );

	newAntScriptContents = newAntScriptContents.replace( /__ADMIN_PASSWORD__/g,
		mainHttpServerPassword );

	newAntScriptContents = newAntScriptContents.replace( /__NCHOME__/g, getNchome() );


	var newAntScript = transformPathSeparators( getNchome() + "/etc/" + target + "/antonce/" + machantScript );
	createFolders( transformPathSeparators( getNchome() + "/etc/" + target + "/antonce/" ) );

	writeToFile( newAntScript , newAntScriptContents );

	log( 3, "MachAnt script processing completed." );
}

/**
 * Post-install function to make the necessary modifications to turbine resources
 * files for the Precision web applications.
 */
function updateVelocityPortletConfig(modulePackage)
{
	log( 2, "Updating TurbineResources.properties file..." );

	// Carry out the Velocity portlet configuration by modifying the TurbineResources.properties file.
	try
	{
		modifyTurbineResources(modulePackage);
	}
	catch ( e )
	{
		log( 0, "Error making additions to the TurbineResources.properties file : " + e );
	}

	log( 3, "TurbineResources.properties processing completed." );
}


/**
 * Post-remove script to make the necessary modifications to turbine resources
 * files for the Precision web applications.
 */
function removeVelocityPortletConfig(modulePackage)
{
	log( 2, "Updating TurbineResources.properties" );

	// Remove package from Velocity portlet configuration by modifying the TurbineResources.properties file.
	try
	{
		removeTurbineResourceModifications(modulePackage);
	}
	catch ( e )
	{
		log( 0, "Error removing classpath from the TurbineResources.properties file : " + e );
	}

	log( 3, "TurbineResources.properties processing completed." );
}


/**
 * Makes additions to the turbineResources.properties file used to register
 * the action classes for velocity portlet customised configuration pages.
 */
function modifyTurbineResources(modulePackage)
{
	log( 2, "Inserting into TurbineResources.properties module package : " + modulePackage );

	var propFilename = getTurbineResourcesFilename();

	var lineToBeInserted = "module.packages="+modulePackage;

	log( 3, "Checking turbine resources file " + propFilename );

	// Create and initialise the file.
	var file = Components.classes["@mozilla.org/file/local;1"].createInstance( Components.interfaces.nsILocalFile );
	// NOTE: This will not work with Mac!
	file.initWithPath( propFilename );

	// Create an input stream to read in the file.
	var inStream = Components.classes["@mozilla.org/network/file-input-stream;1"].createInstance();

	if (inStream)
	{
		inStream.QueryInterface(Components.interfaces.nsIFileInputStream);

		try
		{
			inStream.init(file, 0x01, 0444, 0);

			inStream.QueryInterface(Components.interfaces.nsILineInputStream);

			// read the file in line by line, adding in a line for the package
			// if the file has not been modified already.
			var line = {}, hasmore;
			var newFileContents = "";
			var alreadyModified = false;
			var insertTally = 0;

			do
			{
				hasmore = inStream.readLine(line);
				if (line.value.indexOf("module.packages=org.apache.turbine.modules") > -1)
				{
					newFileContents += line.value;
					newFileContents += getEndOfLineChars();
					newFileContents += lineToBeInserted;
					newFileContents += getEndOfLineChars();
				}
				else
				{
					if (line.value.indexOf(lineToBeInserted) > -1)
					{
						log( 3, line.value + " already exists in TurbineResources.properties" );
						alreadyModified = true;
					}
					else
					{
						newFileContents += line.value;
						newFileContents += getEndOfLineChars();
					}

				}


			} while(hasmore);

			if (alreadyModified == false)
			{
				// Backup existing TurbineResources.properties file to TurbineResources.properties.orig
				backupFile( propFilename );

				// Write out the new cgi.group file.
				writeToFile( propFilename, newFileContents );

				log( 2, "Path to velocity action class added by Precision install. Original version stored as TurbineResources.properties.orig");
			}
		}
		catch ( e )
		{
			log( 0, e );
		}
		finally
		{
			inStream.close();
		}
	}
}


/**
 * Removes the specified package from the turbineResources.properties file.
 */
function removeTurbineResourceModifications(modulePackage)
{
	log( 2, "Removing from TurbineResources.properties module package : " + modulePackage );

	var propFilename = getTurbineResourcesFilename();

	var lineToBeDeleted = "module.packages=" + modulePackage;

	log( 3, "Checking turbine resources file " + propFilename );

	// Create and initialise the file.
	var file = Components.classes["@mozilla.org/file/local;1"].createInstance( Components.interfaces.nsILocalFile );
	// NOTE: This will not work with Mac!
	file.initWithPath( propFilename );

	// Create an input stream to read in the file.
	var inStream = Components.classes["@mozilla.org/network/file-input-stream;1"].createInstance();

	if (inStream)
	{
		inStream.QueryInterface(Components.interfaces.nsIFileInputStream);

		try
		{
			inStream.init(file, 0x01, 0444, 0);

			inStream.QueryInterface(Components.interfaces.nsILineInputStream);

			// read the file in line by line, checking to see if the file
			// contains the line to be deleted.
			var line = {}, hasmore;
			var newFileContents = "";
			var alreadyModified = true;

			do
			{
				hasmore = inStream.readLine(line);
				if (line.value.indexOf(lineToBeDeleted) > -1)
				{
					alreadyModified = false;
				}
				else
				{
					newFileContents += line.value;
					newFileContents += getEndOfLineChars();
				}


			} while(hasmore);

			if (alreadyModified == false)
			{
				// Backup existing TurbineResources.properties file to TurbineResources.properties.orig
				backupFile( propFilename );

				// Write out the new cgi.group file.
				writeToFile( propFilename, newFileContents );

				log( 2, "Path to velocity action class removed by Precision uninstall. Original version stored as TurbineResources.properties.orig");
			}
		}
		catch ( e )
		{
			log( 0, e );
		}
		finally
		{
			inStream.close();
		}
	}
}


/**
 * Returns the filename, including the path, of the TurbineResources.properties file.
 */
function getTurbineResourcesFilename()
{
	var propFilename = getNchome();

	if ( ncipackage.shortArch == "win32" )
	{
		propFilename += "\\guifoundation\\webapps\\desktop\\WEB-INF\\conf\\TurbineResources.properties";
	}
	else
	{
		propFilename += "/guifoundation/webapps/desktop/WEB-INF/conf/TurbineResources.properties";
	}

	return propFilename;
}

/**
********************************************************************************
*
* WritePrecisionPropsFile()
*
* Function to update the $NCHOME/etc/precision/precision.properties file to
* reflect the NCIM login details configured during the install.
*
********************************************************************************
*/
function WritePrecisionPropsFile()
{
    //
    // Set up the command line args to use for the script
    //
    var cfgArgs = "\"" + PropertyValue("NCIM.SERVER") + "\" "
                + "\"" + PropertyValue("NCIM.DBNAME") + "\" "
                + "\"" + PropertyValue("NCIM.NCIMSCHEMA") + "\" "
                + "\"" + PropertyValue("NCIM.GUISCHEMA") + "\" "
                + "\"" + PropertyValue("NCIM.MIBSCHEMA") + "\" "
                + "\"" + PropertyValue("NCIM.MONITORSCHEMA") + "\" "
                + "\"" + PropertyValue("NCIM.HOST") + "\" "
                + "\"" + PropertyValue("NCIM.PORT") + "\" "
                + "\"" + PropertyValue("NCIM.USERNAME") + "\" "
                + "\"" + PropertyValue("NCIM.PASSWORD") + "\" "
                + "\"true\"";   // encrypt password

    //
    // Set up platform specific variables
    //
    var slash = "/";
    var topLine = "#!/bin/sh";
    var pathSepr = ":";
    var javaExt = "";
    var javaVer = "jre_1.5.0";

    if (ncipackage.shortArch == "win32")
    {
        slash = "\\";
        topLine = "@echo off";
        pathSepr = ";";
        javaExt = ".exe";
    }

    if (ncipackage.shortArch == "aix5")
    {
        javaVer = "jre_1.4.2";
    }

    var classPath = GetNcHome() + slash + "guifoundation" + slash + "common" + slash + "lib" + slash
                  + "ncp_portlet_common.jar" + pathSepr
                  + GetNcHome() + slash + "guifoundation" + slash + "common" + slash + "lib" + slash
                  + "xmlrpc-1.2-b1.jar";

    var javaCmd = GetNcHome() + slash
                + "platform" + slash
                + ncipackage.shortArch + slash
                + javaVer + slash
                + "bin" + slash
                + "java" + javaExt;

    //
    // Now attempt to execute a script use the PrecisonConfigStore class to
    // write an updated precision.properties file
    //
    try
    {
        //
        // Now create a script to run the relocation of Perl
        //
        var scriptFileName = GetNcHome() + slash + "ncp_precisionprops.bat";

        var scriptFile = Components.classes["@mozilla.org/file/local;1"].
            createInstance(Components.interfaces.nsILocalFile);
        scriptFile.initWithPath(scriptFileName);

        var scriptContents = topLine + "\n"
                           + "\""+ javaCmd
                           + "\" -Dnchome=\"" + GetNcHome() + "\""
                           + " -classpath \"" + classPath + "\""
                           + " com.micromuse.precision.common.PrecisionConfigStore " + cfgArgs
                           + " > \""
                           + GetNcHome() + slash + "log" + slash
                           + "install" + slash + "ncp_precisionprops.log\" 2>&1\n";

        var foStream2 = Components.classes["@mozilla.org/network/file-output-stream;1"].
            createInstance(Components.interfaces.nsIFileOutputStream);
        foStream2.init(scriptFile, 0x02 | 0x08 | 0x20, 0777, 0); // write, create, truncate
        foStream2.write(scriptContents, scriptContents.length);
        foStream2.close();

        //
        // Now run the script.
        //
        var process = Components.classes["@mozilla.org/process/util;1"].
            createInstance(Components.interfaces.nsIProcess);
        process.init(scriptFile);

        var args = [];
        process.run(true, args, args.length);

        //
        // Finally, clean up the temporary file.
        //
        scriptFile.remove(false);
    }
    catch(e)
    {
        Log(0, e);
    }
}
