/******************************************************************/
/*                                                                */
/* Copyright (C) 1994 - 2005, Micromuse, Ltd.                     */
/* All Rights Reserved                                            */
/*                                                                */
/*----------------------------------------------------------------*/
/*                                                                */
/* THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE                    */
/* The copyright notice above does not evidence any               */
/* actual or intended publication of such source code.            */
/*                                                                */
/* RESTRICTED RIGHTS:                                             */
/*                                                                */
/* This file may have been supplied under a license.              */
/* It may be used, disclosed, and/or copied only as permitted     */
/* under such license agreement. Any copy must contain the        */
/* above copyright notice and this restricted rights notice.      */
/* Use, copying, and/or disclosure of the file is strictly        */
/* prohibited unless otherwise provided in the license agreement. */
/*                                                                */
/******************************************************************/

/**
********************************************************************************
*
* CreateAutoProvisionConfigFile()
*
* Function to create a default.xml file,
* with "DOMAIN" substituted for the name of the Precision Domain
*
********************************************************************************
*/
function CreateAutoProvisionConfigFile()
{
	//
	// Set up platform specific variables
	//
	var separator = "/";
	
	if (ncipackage.shortArch == "win32")
	{
	    separator = "\\";
	}

	var domainName = PropertyValue("PRECISION.DOMAIN0");	
	var replaceRegex = new RegExp("\"DOMAIN\"", "g");
	var configFile = "default.xml";
	
	var autoprovisionPath = GetNcHome() + separator + "etc" + separator
		    + "precision" + separator + "autoprovision" + separator;
	var srcFile    = autoprovisionPath + "default" + separator + configFile;
	var destFile   = autoprovisionPath + configFile;
	

	CreateConfigFile (replaceRegex,domainName,srcFile,destFile);    
}

/**
********************************************************************************
*
* CreateConfigFile(replaceRegex,newStr,defaultFileName,newFileName)
*
* Function to create a configuration file by copying the 
* default file and then applying a regular expression to modify it.
*
********************************************************************************
*/
function CreateConfigFile(replaceRegex,newStr,defaultFileName,newFileName)
{    
    if (newStr.length > 0)
    {        
        try
        {            
            var newFile = Components.classes["@mozilla.org/file/local;1"].
                createInstance(Components.interfaces.nsILocalFile);
            newFile.initWithPath(newFileName);

             
            var defaultFile = Components.classes["@mozilla.org/file/local;1"].
                    createInstance(Components.interfaces.nsILocalFile);
            defaultFile.initWithPath(defaultFileName);

            if (defaultFile.exists())
            {
                    var defaultCfgFile = ReadFile(defaultFile);

                    var newCfgFile = defaultCfgFile.replace(replaceRegex,
                                                                      "\"" + newStr + "\"");

                    var foStream = Components.classes["@mozilla.org/network/file-output-stream;1"].
                        createInstance(Components.interfaces.nsIFileOutputStream);
                    foStream.init(newFile, 0x02 | 0x08 | 0x20, 0666, 0); // write, create, truncate
                    foStream.write(newCfgFile, newCfgFile.length);
                    foStream.close();
            }
            else
            {
                    Log(1, "Not creating " + newFileName + " because the template "
                         + defaultFileName + " doesn't exist");
            }            
        }
        catch(e)
        {
            Log(0, e);
        }
    }
    else
    {
        Log(0, "Unable to create " + newFileName + " as Precision domain "
             + " not available.");
    }
}